@@ -159,7 +159,7 @@ ExerciseFactorize::ExerciseFactorize(QWidget * parent) :
     m_skipButton = new QPushButton(this);
     m_skipButton->setObjectName(QStringLiteral("m_skipButton"));
     m_skipButton->setText(i18n("&Skip"));
-    m_skipButton->setToolTip(i18n("Click on this button to skip this question."));
+    m_skipButton->setToolTip(i18nc("@info:tooltip", "Click on this button to skip this question."));
     m_skipButton->setFont(defaultFont);
     QObject::connect(m_skipButton, &QPushButton::clicked, this, &ExerciseFactorize::slotSkipButtonClicked);
     checkLayout->addWidget(m_skipButton, 1, 1);
@@ -168,7 +168,7 @@ ExerciseFactorize::ExerciseFactorize(QWidget * parent) :
     m_checkButton = new QPushButton(this);
     m_checkButton->setObjectName(QStringLiteral("m_checkButton"));
     m_checkButton->setText(i18n("&Check"));
-    m_checkButton->setToolTip(i18n("Click on this button to check your result. The button will not work if you have not entered a result yet."));
+    m_checkButton->setToolTip(i18nc("@info:tooltip", "Click on this button to check your result. The button will not work if you have not entered a result yet."));
     QObject::connect(m_checkButton, &QPushButton::clicked, this, &ExerciseFactorize::slotCheckButtonClicked);
     m_checkButton->setFont(defaultFont);
     m_checkButton->setDefault(true);  // is the default button of the dialog
@@ -213,19 +213,19 @@ ExerciseFactorize::ExerciseFactorize(QWidget * parent) :
     QObject::connect(m_factor19Button, &QPushButton::clicked, this, &ExerciseFactorize::slotFactor19ButtonClicked);
 
     // add tooltips to the factor buttons
-    m_factor2Button->setToolTip(i18n("Add prime factor 2."));
-    m_factor3Button->setToolTip(i18n("Add prime factor 3."));
-    m_factor5Button->setToolTip(i18n("Add prime factor 5."));
-    m_factor7Button->setToolTip(i18n("Add prime factor 7."));
-    m_factor11Button->setToolTip(i18n("Add prime factor 11."));
-    m_factor13Button->setToolTip(i18n("Add prime factor 13."));
-    m_factor17Button->setToolTip(i18n("Add prime factor 17."));
-    m_factor19Button->setToolTip(i18n("Add prime factor 19."));
+    m_factor2Button->setToolTip(i18nc("@info:tooltip", "Add prime factor 2."));
+    m_factor3Button->setToolTip(i18nc("@info:tooltip", "Add prime factor 3."));
+    m_factor5Button->setToolTip(i18nc("@info:tooltip", "Add prime factor 5."));
+    m_factor7Button->setToolTip(i18nc("@info:tooltip", "Add prime factor 7."));
+    m_factor11Button->setToolTip(i18nc("@info:tooltip", "Add prime factor 11."));
+    m_factor13Button->setToolTip(i18nc("@info:tooltip", "Add prime factor 13."));
+    m_factor17Button->setToolTip(i18nc("@info:tooltip", "Add prime factor 17."));
+    m_factor19Button->setToolTip(i18nc("@info:tooltip", "Add prime factor 19."));
 
     // the remove last factor button
     m_removeLastFactorButton->setEnabled(false);
     QObject::connect(m_removeLastFactorButton, &QPushButton::clicked, this, &ExerciseFactorize::slotRemoveLastFactorButtonClicked);
-    m_removeLastFactorButton->setToolTip(i18n("Removes the last entered prime factor."));
+    m_removeLastFactorButton->setToolTip(i18nc("@info:tooltip", "Removes the last entered prime factor."));
 
     m_factor2Button->setFocusPolicy(Qt::NoFocus);
     m_factor3Button->setFocusPolicy(Qt::NoFocus);
@@ -242,7 +242,7 @@ ExerciseFactorize::ExerciseFactorize(QWidget * parent) :
     checkWidget->setLayout(checkLayout);
 
     // add tooltip and qwhatsthis help to the widget
-    setToolTip(i18n("In this exercise you have to factorize a given number."));
+    setToolTip(i18nc("@info:tooltip", "In this exercise you have to factorize a given number."));
     setWhatsThis(i18n("In this exercise you have to factorize a given number. You have to enter all prime factors of the number. You can add a prime factor by clicking on the corresponding button. The chosen prime factors will be shown in the input field. Do not forget to enter all prime factors, even when a prime factor repeats several times. Click the 'Backspace' button to remove the last entered prime factor."));
 
     m_edit = true;
@@ -346,7 +346,7 @@ void ExerciseFactorize::showResult()
     uint uint_result = 0;
 
     // change the tooltip of the check button
-    m_checkButton->setToolTip(i18n("Click on this button to get to the next question."));
+    m_checkButton->setToolTip(i18nc("@info:tooltip", "Click on this button to get to the next question."));
 
     // disable prime factor buttons
     m_factor2Button->setEnabled(false);
@@ -397,7 +397,7 @@ void ExerciseFactorize::showResult()
 void ExerciseFactorize::nextTask()
 {
     // change the tooltip of the check button
-    m_checkButton->setToolTip(i18n("Click on this button to check your result. The button will not work if you have not entered a result yet."));
+    m_checkButton->setToolTip(i18nc("@info:tooltip", "Click on this button to check your result. The button will not work if you have not entered a result yet."));
 
     // enable prime factor buttons
     m_factor2Button->setEnabled(true);
