@@ -1,23 +1,12 @@
-/***************************************************************************
-                  FractionBaseWidget.h  -  base fraction painting
-                             -------------------
-    begin                : 2004/05/30
-    copyright            : (C) 2004 by Sebastian Stein
-    email                : seb.kde@hpfsc.de
+/*
+    FractionBaseWidget.cpp  -  base fraction painting
+    SPDX-FileCopyrightText: 2004 Sebastian Stein <seb.kde@hpfsc.de>
+    SPDX-FileCopyrightText: 2008 Tiago Porangaba <tiago.porangaba@ltia.fc.unesp.br>
+    SPDX-FileCopyrightText: 2008 Tadeu Araujo <tadeu.araujo@ltia.fc.unesp.br>
+    SPDX-FileCopyrightText: 2008 Danilo Balzaque <danilo.balzaque@ltia.fc.unesp.br>
 
-    copyright            : (C) 2008 by Tiago Porangaba, tiago.porangaba@ltia.fc.unesp.br
-    copyright            : (C) 2008 by Tadeu Araujo, tadeu.araujo@ltia.fc.unesp.br
-    copyright            : (C) 2008 by Danilo Balzaque, danilo.balzaque@ltia.fc.unesp.br
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef FRACTIONBASEWIDGET_H
 #define FRACTIONBASEWIDGET_H
@@ -41,13 +30,13 @@ public:
     explicit FractionBaseWidget(QWidget * parent = nullptr);
 
     /** destructor */
-    ~FractionBaseWidget();
+    ~FractionBaseWidget() override;
 
     /** updates the widget by first getting the settings and then repainting */
     void updateAndRepaint();
 
 protected:
-    QSize minimumSizeHint() const Q_DECL_OVERRIDE {
+    QSize minimumSizeHint() const override {
         return QSize(20, 10);
     }
 
